==> knative-model-6.5.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingListFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KafkaBindingListFluent<A extends KafkaBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,KafkaBinding item);
  public A setToItems(Integer index,KafkaBinding item);
  public A addToItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public A addAllToItems(Collection<KafkaBinding> items);
  public A removeFromItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public A removeAllFromItems(Collection<KafkaBinding> items);
  public A removeMatchingFromItems(Predicate<KafkaBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KafkaBinding> getItems();
  public List<KafkaBinding> buildItems();
  public KafkaBinding buildItem(Integer index);
  public KafkaBinding buildFirstItem();
  public KafkaBinding buildLastItem();
  public KafkaBinding buildMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public A withItems(List<KafkaBinding> items);
  public A withItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public Boolean hasItems();
  public KafkaBindingListFluent.ItemsNested<A> addNewItem();
  public KafkaBindingListFluent.ItemsNested<A> addNewItemLike(KafkaBinding item);
  public KafkaBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,KafkaBinding item);
  public KafkaBindingListFluent.ItemsNested<A> editItem(Integer index);
  public KafkaBindingListFluent.ItemsNested<A> editFirstItem();
  public KafkaBindingListFluent.ItemsNested<A> editLastItem();
  public KafkaBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KafkaBindingFluent<KafkaBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingListFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KafkaBindingListFluent<A extends KafkaBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,KafkaBinding item);
  public A setToItems(int index,KafkaBinding item);
  public A addToItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public A addAllToItems(Collection<KafkaBinding> items);
  public A removeFromItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public A removeAllFromItems(Collection<KafkaBinding> items);
  public A removeMatchingFromItems(Predicate<KafkaBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KafkaBinding> getItems();
  public List<KafkaBinding> buildItems();
  public KafkaBinding buildItem(int index);
  public KafkaBinding buildFirstItem();
  public KafkaBinding buildLastItem();
  public KafkaBinding buildMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public A withItems(List<KafkaBinding> items);
  public A withItems(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaBinding... items);
  public Boolean hasItems();
  public KafkaBindingListFluent.ItemsNested<A> addNewItem();
  public KafkaBindingListFluent.ItemsNested<A> addNewItemLike(KafkaBinding item);
  public KafkaBindingListFluent.ItemsNested<A> setNewItemLike(int index,KafkaBinding item);
  public KafkaBindingListFluent.ItemsNested<A> editItem(int index);
  public KafkaBindingListFluent.ItemsNested<A> editFirstItem();
  public KafkaBindingListFluent.ItemsNested<A> editLastItem();
  public KafkaBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<KafkaBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KafkaBindingFluent<KafkaBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
